@@ -6,7 +6,7 @@ import (
 
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 
-	"github.com/MakeNowJust/heredoc"
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"github.com/xanzy/go-gitlab"
 	"gitlab.com/gitlab-org/cli/api"
@@ -108,43 +108,15 @@ func updateRun(opts *UpdateOpts) error {
 		return err
 	}
 
-	baseRepo, err := opts.BaseRepo()
-	if err != nil {
-		return err
-	}
-
-	if opts.Group == "" {
-		// update project-level variable
-		updateProjectVarOpts := &gitlab.UpdateProjectVariableOptions{
-			Value:            gitlab.String(opts.Value),
-			VariableType:     gitlab.VariableType(gitlab.VariableTypeValue(opts.Type)),
-			Masked:           gitlab.Bool(opts.Masked),
-			Protected:        gitlab.Bool(opts.Protected),
-			Raw:              gitlab.Bool(opts.Raw),
-			EnvironmentScope: gitlab.String(opts.Scope),
-		}
-
-		_, err = api.UpdateProjectVariable(httpClient, baseRepo.FullName(), opts.Key, updateProjectVarOpts)
-		if err != nil {
-			return err
-		}
-
-		fmt.Fprintf(opts.IO.StdOut,
-			"%s Updated variable %s for project %s with scope %s\n",
-			c.GreenCheck(),
-			opts.Key,
-			baseRepo.FullName(),
-			opts.Scope)
-
-	} else {
+	if opts.Group != "" {
 		// update group-level variable
 		updateGroupVarOpts := &gitlab.UpdateGroupVariableOptions{
-			Value:            gitlab.String(opts.Value),
-			VariableType:     gitlab.VariableType(gitlab.VariableTypeValue(opts.Type)),
-			Masked:           gitlab.Bool(opts.Masked),
-			Protected:        gitlab.Bool(opts.Protected),
-			Raw:              gitlab.Bool(opts.Raw),
-			EnvironmentScope: gitlab.String(opts.Scope),
+			Value:            gitlab.Ptr(opts.Value),
+			VariableType:     gitlab.Ptr(gitlab.VariableTypeValue(opts.Type)),
+			Masked:           gitlab.Ptr(opts.Masked),
+			Protected:        gitlab.Ptr(opts.Protected),
+			Raw:              gitlab.Ptr(opts.Raw),
+			EnvironmentScope: gitlab.Ptr(opts.Scope),
 		}
 
 		_, err = api.UpdateGroupVariable(httpClient, opts.Group, opts.Key, updateGroupVarOpts)
@@ -153,7 +125,29 @@ func updateRun(opts *UpdateOpts) error {
 		}
 
 		fmt.Fprintf(opts.IO.StdOut, "%s Updated variable %s for group %s\n", c.GreenCheck(), opts.Key, opts.Group)
+		return nil
 	}
 
+	// update project-level variable
+	baseRepo, err := opts.BaseRepo()
+	if err != nil {
+		return err
+	}
+
+	updateProjectVarOpts := &gitlab.UpdateProjectVariableOptions{
+		Value:            gitlab.Ptr(opts.Value),
+		VariableType:     gitlab.Ptr(gitlab.VariableTypeValue(opts.Type)),
+		Masked:           gitlab.Ptr(opts.Masked),
+		Protected:        gitlab.Ptr(opts.Protected),
+		Raw:              gitlab.Ptr(opts.Raw),
+		EnvironmentScope: gitlab.Ptr(opts.Scope),
+	}
+
+	_, err = api.UpdateProjectVariable(httpClient, baseRepo.FullName(), opts.Key, updateProjectVarOpts)
+	if err != nil {
+		return err
+	}
+
+	fmt.Fprintf(opts.IO.StdOut, "%s Updated variable %s for project %s with scope %s\n", c.GreenCheck(), opts.Key, baseRepo.FullName(), opts.Scope)
 	return nil
 }
